@@ -92,20 +92,6 @@ void * liquid_error_config_fl(const char * _file, int _line, const char * _forma
 // MODULE : fec (forward error-correction)
 //
 
-// checksum / cyclic redundancy check (crc)
-
-#define CRC8_POLY 0x07
-#define CRC16_POLY 0x8005
-#define CRC24_POLY 0x5D6DCB
-#define CRC32_POLY 0x04C11DB7
-
-unsigned int checksum_generate_key(unsigned char * _msg, unsigned int _msg_len);
-unsigned int crc8_generate_key(unsigned char * _msg, unsigned int _msg_len);
-unsigned int crc16_generate_key(unsigned char * _msg, unsigned int _msg_len);
-unsigned int crc24_generate_key(unsigned char * _msg, unsigned int _msg_len);
-unsigned int crc32_generate_key(unsigned char * _msg, unsigned int _msg_len);
-
-
 // fec : basic object
 struct fec_s {
     // common
@@ -794,22 +780,6 @@ float estimate_req_filter_len_Herrmann(float _df,
 float rkaiser_approximate_rho(unsigned int _m,
                               float _beta);
 
-// Design frequency-shifted root-Nyquist filter based on
-// the Kaiser-windowed sinc using the bisection method
-//
-//  _k      :   filter over-sampling rate (samples/symbol)
-//  _m      :   filter delay (symbols)
-//  _beta   :   filter excess bandwidth factor (0,1)
-//  _dt     :   filter fractional sample delay
-//  _h      :   resulting filter, [size: 2*_k*_m+1]
-//  _rho    :   transition bandwidth adjustment, 0 < _rho < 1
-int liquid_firdes_rkaiser_bisection(unsigned int _k,
-                                    unsigned int _m,
-                                    float _beta,
-                                    float _dt,
-                                    float * _h,
-                                    float * _rho);
-
 // Design frequency-shifted root-Nyquist filter based on
 // the Kaiser-windowed sinc using the quadratic method.
 //
@@ -1153,7 +1123,7 @@ float complex liquid_cacosf(float complex _z);
 float complex liquid_catanf(float complex _z);
 
 // faster approximation to arg{*}
-float liquid_cargf_approx(float complex _z);
+//float liquid_cargf_approx(float complex _z);
 
 
 // internal trig helper functions
@@ -1381,19 +1351,6 @@ int MODEM(_demodulate_soft_table)(MODEM()         _q,           \
                                   unsigned int *  _sym_out,     \
                                   unsigned char * _soft_bits);  \
                                                                 \
-/* Demodulate a linear symbol constellation using dynamic   */  \
-/* threshold calculation                                    */  \
-/*  _v      :   input value             */                      \
-/*  _m      :   bits per symbol         */                      \
-/*  _alpha  :   scaling factor          */                      \
-/*  _s      :   demodulated symbol      */                      \
-/*  _res    :   residual                */                      \
-int MODEM(_demodulate_linear_array)(T              _v,          \
-                                    unsigned int   _m,          \
-                                    T              _alpha,      \
-                                    unsigned int * _s,          \
-                                    T *            _res);       \
-                                                                \
 /* Demodulate a linear symbol constellation using           */  \
 /* referenced lookup table                                  */  \
 /*  _v      :   input value             */                      \
