@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007 - 2022 Joseph Gaeddert
+ * Copyright (c) 2007 - 2023 Joseph Gaeddert
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -58,7 +58,7 @@ const char * liquid_window_str[LIQUID_WINDOW_NUM_FUNCTIONS][2] = {
 };
 
 // Print compact list of existing and available windowing functions
-void liquid_print_windows()
+int liquid_print_windows()
 {
     unsigned int i;
     unsigned int len = 10;
@@ -78,6 +78,7 @@ void liquid_print_windows()
         }
     }
     printf("\n");
+    return LIQUID_OK;
 }
 
 // returns modulation_scheme based on input string
@@ -91,7 +92,7 @@ liquid_window_type liquid_getopt_str2window(const char * _str)
         }
     }
 
-    fprintf(stderr,"warning: liquid_getopt_str2window(), unknown/unsupported window scheme : %s\n", _str);
+    liquid_error(LIQUID_EICONFIG,"liquid_getopt_str2window(), unknown/unsupported window scheme: %s", _str);
     return LIQUID_WINDOW_UNKNOWN;
 }
 
