@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007 - 2023 Joseph Gaeddert
+ * Copyright (c) 2007 - 2024 Joseph Gaeddert
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -84,6 +84,7 @@ struct ofdmframesync_s {
     unsigned int M2;        // number of subcarriers (divided by 2)
     unsigned int cp_len;    // cyclic prefix length
     unsigned char * p;      // subcarrier allocation (null, pilot, data)
+    unsigned int taper_len; // number of samples in tapering window/overlap
 
     // constants
     unsigned int M_null;    // number of null subcarriers
@@ -183,8 +184,6 @@ ofdmframesync ofdmframesync_create(unsigned int           _M,
                                    ofdmframesync_callback _callback,
                                    void *                 _userdata)
 {
-    ofdmframesync q = (ofdmframesync) malloc(sizeof(struct ofdmframesync_s));
-
     // validate input
     if (_M < 8)
         return liquid_error_config("ofdmframesync_create(), number of subcarriers must be at least 8");
@@ -195,8 +194,11 @@ ofdmframesync ofdmframesync_create(unsigned int           _M,
     if (_taper_len > _cp_len)
         return liquid_error_config("ofdmframesync_create(), taper length cannot exceed cyclic prefix");
 
+    // allocate object and set parameters
+    ofdmframesync q = (ofdmframesync) malloc(sizeof(struct ofdmframesync_s));
     q->M = _M;
     q->cp_len = _cp_len;
+    q->taper_len = _taper_len;
 
     // derived values
     q->M2 = _M/2;
@@ -346,10 +348,14 @@ int ofdmframesync_destroy(ofdmframesync _q)
 
 int ofdmframesync_print(ofdmframesync _q)
 {
-    printf("ofdmframesync:\n");
-    printf("    num subcarriers     :   %-u\n", _q->M);
-    printf("    cyclic prefix len   :   %-u\n", _q->cp_len);
-    //printf("    taper len           :   %-u\n", _q->taper_len);
+    printf("<liquid.ofdmframesync");
+    printf(", subcarriers=%u", _q->M);
+    printf(", null=%u", _q->M_null);
+    printf(", pilot=%u", _q->M_pilot);
+    printf(", data=%u", _q->M_data);
+    printf(", cp=%u", _q->cp_len);
+    printf(", taper=%u", _q->taper_len);
+    printf(">\n");
     return LIQUID_OK;
 }
 
@@ -475,7 +481,7 @@ int ofdmframesync_execute_seekplcp(ofdmframesync _q)
 
     // estimate gain
     unsigned int i;
-    // start with a reasonably small number to avoid divide-by-zero warning
+    // start with a reasonably small number to avoid division by zero
     float g = 1.0e-9f;
     for (i=_q->cp_len; i<_q->M + _q->cp_len; i++) {
         // compute |rc[i]|^2 efficiently
@@ -932,7 +938,7 @@ int ofdmframesync_estimate_eqgain(ofdmframesync _q,
 
         // eliminate divide-by-zero issues
         if (cabsf(w0) < 1e-4f) {
-            fprintf(stderr,"warning: ofdmframesync_estimate_eqgain(), weighting factor is zero\n");
+            liquid_error(LIQUID_EINT,"ofdmframesync_estimate_eqgain(), weighting factor is zero");
             w0 = 1.0f;
         }
         _q->G[i] = G_hat / w0;
